==> cmsmadesimple-1.9.4.3-full.tar.gz: modules/FileManager/lang/ext/it_IT.php <==
<?php
$lang['friendlyname'] = 'File Manager ';
$lang['permission'] = 'Uso del modulo File Manager';
$lang['permissionadvanced'] = 'Uso avanzato del modulo File Manager';
$lang['moddescription'] = 'Associazione di files e directory nella sezione upload di cmsms';
$lang['installed'] = 'Versione del FileManager %s installata';
$lang['postinstall'] = 'Il modulo FileManager era installato';
$lang['uninstalled'] = 'Modulo FileManager disinstallato';
$lang['really_uninstall'] = 'Siete sicuri di volere disinstallare il modulo FileManager?';
$lang['upgraded'] = 'Il modulo FileManager &egrave; stato aggiornato alla versione %s';
$lang['fileview'] = 'Visualizza file';
$lang['switchtofileview'] = 'Passa alla visualizzazione file';
$lang['settings'] = 'Impostazioni';
$lang['savesettings'] = 'Salva Impostazioni';
$lang['postletexists'] = 'Attenzione! Si prega di rimuovere completamente la cartella modules/FileManager/postlet poich&egrave; obsoleta e pericolosa.';
$lang['filename'] = 'Nome file';
$lang['fileinfo'] = 'Info file';
$lang['fileowner'] = 'Possessore del file';
$lang['fileperms'] = 'Permessi';
$lang['filesize'] = 'Dimensione';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Azioni';
$lang['delete'] = 'Elimina';
$lang['notwritable'] = 'Non scrivibile';
$lang['afileistoobig'] = 'Un file &egrave; troppo grande. Upload cancellato.';
$lang['unknown'] = 'Sconosciuto';
$lang['fileoutsideuploads'] = 'Voi non avete il permesso di modificare file al di fuori della directory di uploads! (Questo richiede permessi di Advanced File Management)';
$lang['writable'] = 'Scrivibile';
$lang['writeprotected'] = 'Protetto da scrittura';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'KB';
$lang['mb'] = 'MB';
$lang['files'] = 'file';
$lang['bytesin'] = 'bytes in ';
$lang['in'] = 'in ';
$lang['file'] = 'file ';
$lang['fileno'] = 'File numero';
$lang['subdirs'] = 'sottodirectory';
$lang['subdir'] = 'sottodirectory';
$lang['and'] = 'e';
$lang['confirmsingledelete'] = 'Siete sicuri?';
$lang['confirmsingledirdelete'] = 'Siete sicuri di volere cancellare questa directory?';
$lang['dirtreedeletesuccess'] = 'La directory e tutto il suo contenuto &egrave; stata cancellata con successo.';
$lang['dirtreedeletefail'] = 'C&#039;&egrave; stato un errore durante l&#039;eliminazione di questa directory. Tuttavia una parte del contenuto potrebbe essere stata cancellata.';
$lang['singlefiledeletesuccess'] = 'Il file &egrave; stato eliminato con successo';
$lang['filedeletesuccess'] = '&egrave; stato eliminato con successo';
$lang['singlefiledeletefail'] = 'Si &egrave; verificato un errore durante l&#039;eliminazione del file';
$lang['filedeletefail'] = 'non &egrave; stato eliminato a causa di un errore';
$lang['singledirdeletesuccess'] = 'La directory &egrave; stata eliminata con successo';
$lang['singledirdeletefail'] = 'Si &egrave; verificato un errore cercando di eliminare la directory (&egrave; vuota?)';
$lang['deleteselected'] = 'Elimina i file selezionati';
$lang['confirmselected'] = 'Siete sicuri?';
$lang['confirmdeleteselected'] = 'Siete sicuri che i file selezionati devono essere cancellati?';
$lang['deleteselectedcancelled'] = 'Cancellazione dei file selezionati annullata';
$lang['recursetext'] = 'Ricorsivo nelle sottodirectory (non ancora implementato)';
$lang['nofilesselected'] = 'Nessun file selezionato';
$lang['moveselected'] = 'Muove i file selezionati';
$lang['copyselected'] = 'Copia i file selezionati';
$lang['selecttargetdir'] = 'Selezionate la directory di arrivo per muovere/copiare';
$lang['movedto'] = 'mosso a';
$lang['copiedto'] = 'copiato a';
$lang['couldnotmove'] = 'non pu&ograve; essere mosso';
$lang['couldnotcopy'] = 'non pu&ograve; essere copiato';
$lang['filesdeletedsuccessfully'] = '%s file(s) sono stati cancellati con successo';
$lang['filesdeletedfiled'] = '%s file(s) fallita la cancellazione';
$lang['filesmovedsuccessfully'] = '%s file(s) sono stati mossi con successo';
$lang['filesmovedfailed'] = '%s file(s) fallito lo spostamento';
$lang['filescopiedsuccessfully'] = '%s file(s) sono stati copiati con successo';
$lang['filescopiedfailed'] = '%s file(s) fallito da copiare';
$lang['internalerror'] = 'Errore Interno (significa qualche operazione fallita, si prega di riportare l&#039;operazione effettuata)';
$lang['rename'] = 'Rinomina';
$lang['newname'] = 'Nuovo nome:';
$lang['renamesuccess'] = 'File rinominato correttamente';
$lang['renamefailure'] = 'Modifica del nome fallita';
$lang['renamecancelled'] = 'Modifica del nome annullata';
$lang['owner'] = 'Proprietario';
$lang['group'] = 'Gruppo';
$lang['others'] = 'Altri';
$lang['newpermissions'] = 'Nuovi permessi:';
$lang['setpermissions'] = 'Imposta permessi';
$lang['permissionstyle'] = 'Stile permessi';
$lang['rwxstyle'] = 'stile rwx';
$lang['755style'] = 'stile 755';
$lang['quickmode'] = 'chmod veloce (like 777)';
$lang['chmod'] = 'Cambia permessi';
$lang['chmodselected'] = 'Cambia permessi sui file selezionati';
$lang['chmodsuccess'] = 'File modificato con i nuovi permessi';
$lang['chmodfailure'] = 'Cambio dei permessi del file fallito';
$lang['chmodcancelled'] = 'Cambio dei permessi cancellato';
$lang['newuploadfailed'] = '%s file(s) fallito l&#039;upload (o l&#039;eventuale decompressione)';
$lang['newuploadsuccess'] = '%s file(s) uploaded con successo (e l&#039;eventuale decompressione se scelta)';
$lang['dirchmodfailmulti'] = 'Il cambio dei permessi sulla directory &egrave; fallito, sebbene alcuni dei componenti potrebbero aver preso i nuovi permessi.';
$lang['dirchmodsuccessmulti'] = 'Il cambio dei permessi sulla directory e i suoi componenti ha avuto successo';
$lang['dirchmodsuccess'] = 'La directory ha preso correttamente i nuovi permessi';
$lang['dirchmodfailure'] = 'Cambio dei permessi della directory fallito';
$lang['dirnotemptyconfirm'] = 'La directory non &egrave; vuota. Volete veramente eliminarla cancellando il suo contenuto, comprese le sottodirectory?';
$lang['dirtreedeletecancelled'] = 'Eliminazione della directory annnullata';
$lang['imsure'] = 'Sono sicuro';
$lang['cancel'] = 'Annulla';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Carica nuovo/i file:';
$lang['unpackafterupload'] = 'Cerca di decomprimere dopo il caricamento (solo file di tipo tgz e zip)?';
$lang['uploadsuccess'] = 'Il file &egrave; stato caricato con successo';
$lang['uploadfail'] = 'Si &egrave; verificato un errore durante il caricamento del file';
$lang['unpacksuccess'] = 'Il file &egrave; stato decompresso con successo';
$lang['unpackfail'] = 'Si &egrave; verificato un errore durante la decompressione del file:';
$lang['packfileopenfail'] = 'Non posso aprire il file compresso per la decompressione (formato non supportato?)';
$lang['packfilewritefail'] = 'Non posso aprire il file %s per la scrittura';
$lang['afilecontainsillegalchars'] = 'A file contiene uno o pi&ugrave; caratteri illegali (&#039;,&quot;,+,*,\,/,&amp;,$). Upload cancellato.';
$lang['currentpath'] = 'Path corrente:';
$lang['newdirname'] = 'Crea nuova directory:';
$lang['newdirsuccess'] = 'La directory &egrave; stata creata con successo';
$lang['newdirfail'] = 'Si &egrave; verificato un errore durante la creazione della directory';
$lang['direxists'] = 'La directory &egrave; gi&agrave; presente';
$lang['invalidnewdir'] = 'Il nome della nuova cartella non pu&ograve; contenere caratteri come /, \ e &#039;..&#039;';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Dimensione Icona';
$lang['smallicons'] = 'Icone Piccole';
$lang['largeicons'] = 'Icone Grandi';
$lang['thousanddelimiter'] = 'Delimitatore delle migliaia';
$lang['none'] = 'Nessuno';
$lang['space'] = 'spazio';
$lang['showthumbnails'] = 'Mostra le miniature';
$lang['showthumbnailshelp'] = 'Abilitando vengono mostrate le miniature dei file immagini se esistono e nascosti i file miniature. Disabilitando vengono mostrati tutti i file.';
$lang['uploadfilesto'] = 'Carica i files in:';
$lang['uploadview'] = 'Carica files';
$lang['uploadboxes'] = 'Numero di blocchi di caricamento';
$lang['nothinguploaded'] = 'Non &egrave; stato caricato nulla';
$lang['newunsupportedarchive'] = '%s &egrave; un formato di archivio non supportato';
$lang['uploadmethod'] = 'Metodo di caricamento';
$lang['uploaderstandard'] = 'Metodo di input html standard (permette la decompressione)';
$lang['enableadvanced'] = 'Abilita modalit&agrave; avanzata?';
$lang['advancedhelp'] = 'Permette di ottenere accesso a tutto il filesystem di CMSMS, non solo della cartella /upload/ (se consentito)';
$lang['showhiddenfileshelp'] = 'Effettivo solo abilitando il modo avanzato';
$lang['showhiddenfiles'] = 'Mostra file nascosti';
$lang['settingsconfirmsingledelete'] = 'Conferma l&#039;eliminazione di un file singolo?';
$lang['settingssaved'] = 'Impostazioni salvate';
$lang['help'] = '		<h3>Cosa fa?</h3>
		<p>Fornisce funzionalit&agrave; di gestione dei file</p>
		<h3>Come si usa?</h3>
		<p>Selezionalo dal menu Contenuto nella sezione di amministrazione.</p>';
$lang['utma'] = '156861353.974349155.1299072468.1299072468.1299072468.1';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
$lang['utmz'] = '156861353.1299072468.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
?>

==> cmsmadesimple-1.11.10-full.tar.gz: modules/FileManager/lang/ext/it_IT.php <==
<?php
$lang['invaliddestname'] = 'Il nome di destinazione specificato &egrave; vuoto o non &egrave; valido';
$lang['copysuccess'] = 'Elementi copiati correttamente';
$lang['copyfailed'] = 'Operazione di copia fallita su %s';
$lang['ie_upload_message'] = 'Drag and Drop, o caricamento multiplo di file non disponibile su Internet Explorer. Per abilitare queste funzioni utilizzate un browser pi&ugrave; potente, come Firefox o Chrome';
$lang['confirm_unpack'] = 'Siete certi di volere scompattare questo archivio?';
$lang['copy_destdir'] = 'Cartella di destinazione';
$lang['copy_destname'] = 'Nome file di destinazione';
$lang['itemstocopy'] = 'Copia questi elementi';
$lang['prompt_copy'] = 'Copia uno o pi&ugrave; elementi';
$lang['movesuccess'] = 'Elementi spostati correttamente';
$lang['movefailed'] = 'Operazione di spostamento fallita su %s';
$lang['fileexistsdest'] = '%s esiste gi&agrave; nella posizione di destinazione';
$lang['insufficientpermission'] = 'Permessi insufficienti per %s';
$lang['invalidmovedir'] = 'La cartella di destinazione specificata non &egrave; valida';
$lang['namealreadyexists'] = 'Il nome esiste gi&agrave;';
$lang['movedestdirsame'] = 'La cartella di destinazione specificata &egrave; la stessa di provenienza';
$lang['prompt_move'] = 'Sposta Elementi in un altra Cartella';
$lang['info_move'] = 'Quest&#039;opzione vi permetter&agrave; di spostare uno o pi&ugrave; elementi in una cartella differente. Utilizzate questa funzione con cautela perch&egrave; potrebbe interrompere collegamenti a file, o altre funzionalit&agrave; del sito';
$lang['itemstomove'] = 'Sposta questi elementi';
$lang['move_destdir'] = 'Cartella di destinazione';
$lang['nodestinationdirs'] = 'Non riesco a trovare cartelle di destinazione valide per questa operazione';
$lang['deletesuccess'] = 'Elementi cancellati correttamente';
$lang['return'] = 'Indietro';
$lang['error_thumbnotwritable'] = '%s ha una miniatura che non possiede permessi di scrittura';
$lang['error_dirnotempty'] = 'La cartella %s non &egrave; vuotais not empty';
$lang['error_notwritable'] = 'Nessun permesso di scrittura su %s';
$lang['actiondelete'] = 'Elimina uno o pi&ugrave; elementi';
$lang['thumberror'] = 'Problemi nella creazione della miniatura';
$lang['thumbsuccess'] = 'Miniatura creata correttamente';
$lang['create'] = 'Crea';
$lang['info_createthumb'] = 'La miniatura seguente verr&agrave; creata';
$lang['createthumbnail'] = 'Crea <em>(o ricrea)</em> la miniatura di un&#039;immagine';
$lang['info_create_thumbnails'] = 'Se abilitato, i file delle miniature delle immagini verranno creati in fase di caricamento';
$lang['create_thumbnails'] = 'Crea miniature al caricamento';
$lang['eventdesc_OnFileUploaded'] = 'Inviato quando viene caricato un file';
$lang['eventhelp_OnFileUploaded'] = '<h4>Parametri:</h4>
<ul>
<li>&quot;file&quot; - La specifica file completa al file caricato.</li>
<li>&quot;thumb&quot; - Se generata, la specifica file completa alla miniatura generata.</li>
</ul>';
$lang['ok'] = 'OK ';
$lang['folder'] = 'Cartella';
$lang['change_working_folder'] = 'Cambia cartella di lavoro';
$lang['prompt_dropfiles'] = 'Trascinate i file qui per caricare';
$lang['refresh'] = 'aggiorna';
$lang['friendlyname'] = 'File Manager ';
$lang['permission'] = 'Uso del modulo File Manager';
$lang['permissionadvanced'] = 'Uso avanzato del modulo File Manager';
$lang['moddescription'] = 'Associazione di files e directory nella sezione upload di cmsms';
$lang['installed'] = 'Versione del FileManager %s installata';
$lang['postinstall'] = 'Il modulo FileManager era installato';
$lang['uninstalled'] = 'Modulo FileManager disinstallato';
$lang['really_uninstall'] = 'Siete sicuri di volere disinstallare il modulo FileManager?';
$lang['upgraded'] = 'Il modulo FileManager &egrave; stato aggiornato alla versione %s';
$lang['fileview'] = 'Visualizza file';
$lang['switchtofileview'] = 'Passa alla visualizzazione file';
$lang['settings'] = 'Impostazioni';
$lang['savesettings'] = 'Salva Impostazioni';
$lang['postletexists'] = 'Attenzione! Si prega di rimuovere completamente la cartella modules/FileManager/postlet poich&egrave; obsoleta e pericolosa.';
$lang['filename'] = 'Nome file';
$lang['fileinfo'] = 'Info file';
$lang['fileowner'] = 'Possessore del file';
$lang['fileperms'] = 'Permessi';
$lang['filesize'] = 'Dimensione';
$lang['filedate'] = 'Data';
$lang['actions'] = 'Azioni';
$lang['newdir'] = 'Nuova cartella';
$lang['createnewdir'] = 'Crea nuova cartella';
$lang['rename'] = 'Rinomina';
$lang['renameerror'] = 'Errore! L&#039;oggetto non pu&ograve; essere rinominato';
$lang['delete'] = 'Elimina';
$lang['thumbnail'] = 'Crea Miniatura';
$lang['copy'] = 'Copia';
$lang['move'] = 'Sposta';
$lang['unpack'] = 'Scompatta';
$lang['notwritable'] = 'Non scrivibile';
$lang['afileistoobig'] = 'Un file &egrave; troppo grande. Caricamento annullato.';
$lang['unknown'] = 'Sconosciuto';
$lang['fileoutsideuploads'] = 'Non avete il permesso di modificare file al di fuori della directory di caricamento! (Richiede permessi di Advanced File Management)';
$lang['writable'] = 'Scrivibile';
$lang['writeprotected'] = 'Protetto da scrittura';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'KB';
$lang['mb'] = 'MB';
$lang['files'] = 'file';
$lang['bytesin'] = 'bytes in ';
$lang['in'] = 'in ';
$lang['file'] = 'file ';
$lang['fileno'] = 'File numero';
$lang['subdirs'] = 'sottodirectory';
$lang['subdir'] = 'sottodirectory';
$lang['and'] = 'e';
$lang['unknownfileaction'] = 'Errore interno: azione su file sconosciuta';
$lang['confirmsingledelete'] = 'Siete sicuri?';
$lang['confirmsingledirdelete'] = 'Siete sicuri di volere cancellare questa directory?';
$lang['dirtreedeletesuccess'] = 'La directory e tutto il suo contenuto &egrave; stata cancellata con successo.';
$lang['dirtreedeletefail'] = 'C&#039;&egrave; stato un errore durante l&#039;eliminazione di questa directory. Tuttavia una parte del contenuto potrebbe essere stata cancellata.';
$lang['singlefiledeletesuccess'] = 'Il file &egrave; stato eliminato con successo';
$lang['filedeletesuccess'] = '&egrave; stato eliminato con successo';
$lang['singlefiledeletefail'] = 'Si &egrave; verificato un errore durante l&#039;eliminazione del file';
$lang['filedeletefail'] = 'non &egrave; stato eliminato a causa di un errore';
$lang['singledirdeletesuccess'] = 'La directory &egrave; stata eliminata con successo';
$lang['singledirdeletefail'] = 'Si &egrave; verificato un errore cercando di eliminare la directory (&egrave; vuota?)';
$lang['deleteselected'] = 'Elimina i file selezionati';
$lang['confirmselected'] = 'Siete sicuri?';
$lang['confirmdeleteselected'] = 'Siete sicuri che i file selezionati devono essere cancellati?';
$lang['deleteselectedcancelled'] = 'Cancellazione dei file selezionati annullata';
$lang['recursetext'] = 'Ricorsivo nelle sottodirectory (non ancora implementato)';
$lang['nofilesselected'] = 'Nessun file selezionato';
$lang['morethanonefiledirselected'] = 'E&#039; possibile contrassegnare solo un file o cartella per questa azione.';
$lang['moveselected'] = 'Sposta i file selezionati';
$lang['copyselected'] = 'Copia i file selezionati';
$lang['selecttargetdir'] = 'Selezionate la directory di arrivo per spostare/copiare';
$lang['movedto'] = 'spostato in';
$lang['copiedto'] = 'copiato in';
$lang['couldnotmove'] = 'non pu&ograve; essere spostato';
$lang['couldnotcopy'] = 'non pu&ograve; essere copiato';
$lang['filesdeletedsuccessfully'] = '%s file cancellati correttamente';
$lang['filesdeletedfiled'] = 'eliminazione fallita di %s file';
$lang['filesmovedsuccessfully'] = '%s file spostati correttamente';
$lang['filesmovedfailed'] = 'spostamento fallito di %s file';
$lang['filescopiedsuccessfully'] = '%s file copiati correttamente';
$lang['filescopiedfailed'] = 'copia fallita di %s file';
$lang['internalerror'] = 'Errore Interno (che significa qualche anomalia non prevista, vi preghiamo di descrivere l&#039;operazione effettuata)';
$lang['newname'] = 'Nuovo nome:';
$lang['renamesuccess'] = 'File rinominato correttamente';
$lang['renamefailure'] = 'Rinomina del file fallita';
$lang['renamecancelled'] = 'Rinomina del file annullata';
$lang['owner'] = 'Proprietario';
$lang['group'] = 'Gruppo';
$lang['others'] = 'Altri';
$lang['newpermissions'] = 'Nuovi permessi:';
$lang['setpermissions'] = 'Imposta permessi';
$lang['permissionstyle'] = 'Stile permessi';
$lang['rwxstyle'] = 'stile rwx';
$lang['755style'] = 'stile 755';
$lang['quickmode'] = 'chmod veloce (come 777)';
$lang['chmod'] = 'Cambia permessi';
$lang['chmodselected'] = 'Cambia permessi sui file selezionati';
$lang['chmodsuccess'] = 'File modificato con i nuovi permessi';
$lang['chmodfailure'] = 'Cambio dei permessi del file fallito';
$lang['chmodcancelled'] = 'Cambio dei permessi cancellato';
$lang['newuploadfailed'] = '%s file(s) fallito l&#039;upload (o l&#039;eventuale decompressione)';
$lang['newuploadsuccess'] = '%s file(s) uploaded con successo (e l&#039;eventuale decompressione se scelta)';
$lang['dirchmodfailmulti'] = 'Il cambio dei permessi sulla directory &egrave; fallito, sebbene alcuni dei componenti potrebbero aver preso i nuovi permessi.';
$lang['dirchmodsuccessmulti'] = 'Il cambio dei permessi sulla directory e i suoi componenti ha avuto successo';
$lang['dirchmodsuccess'] = 'La directory ha preso correttamente i nuovi permessi';
$lang['dirchmodfailure'] = 'Cambio dei permessi della directory fallito';
$lang['dirnotemptyconfirm'] = 'La directory non &egrave; vuota. Volete veramente eliminarla cancellando il suo contenuto, comprese le sottodirectory?';
$lang['dirtreedeletecancelled'] = 'Eliminazione della directory annnullata';
$lang['imsure'] = 'Sono sicuro';
$lang['cancel'] = 'Annulla';
$lang['uploadnewfile'] = 'Carica nuovo/i file:';
$lang['unpackafterupload'] = 'Cerca di decomprimere dopo il caricamento (solo file di tipo tgz e zip)?';
$lang['uploadsuccess'] = 'Il file &egrave; stato caricato con successo';
$lang['uploadfail'] = 'Si &egrave; verificato un errore durante il caricamento del file';
$lang['unpacksuccess'] = 'Il file &egrave; stato decompresso con successo';
$lang['unpackfail'] = 'Si &egrave; verificato un errore durante la decompressione del file:';
$lang['packfileopenfail'] = 'Non posso aprire il file compresso per la decompressione (formato non supportato?)';
$lang['packfilewritefail'] = 'Non posso aprire il file %s per la scrittura';
$lang['afilecontainsillegalchars'] = 'A file contiene uno o pi&ugrave; caratteri illegali (&#039;,&quot;,+,*,\,/,&amp;,$). Upload cancellato.';
$lang['filenotfound'] = 'File non trovato';
$lang['currentpath'] = 'Path corrente:';
$lang['newdirname'] = 'Crea nuova directory:';
$lang['newdirsuccess'] = 'La directory &egrave; stata creata con successo';
$lang['newdirfail'] = 'Si &egrave; verificato un errore durante la creazione della directory';
$lang['direxists'] = 'La directory &egrave; gi&agrave; presente';
$lang['invalidnewdir'] = 'Il nome della nuova cartella non pu&ograve; contenere caratteri come /, \ e &#039;..&#039;';
$lang['filedateformat'] = 'd/m/Y H:m:s';
$lang['iconsize'] = 'Dimensione Icona';
$lang['smallicons'] = 'Icone Piccole';
$lang['largeicons'] = 'Icone Grandi';
$lang['thousanddelimiter'] = 'Delimitatore delle migliaia';
$lang['none'] = 'Nessuno';
$lang['space'] = 'spazio';
$lang['showthumbnails'] = 'Mostra le miniature';
$lang['showthumbnailshelp'] = 'Abilitando vengono mostrate le miniature dei file immagini se esistono e nascosti i file miniature. Disabilitando vengono mostrati tutti i file.';
$lang['uploadfilesto'] = 'Carica i files in:';
$lang['uploadview'] = 'Carica files';
$lang['uploadboxes'] = 'Numero di blocchi di caricamento';
$lang['nothinguploaded'] = 'Non &egrave; stato caricato nulla';
$lang['newunsupportedarchive'] = '%s &egrave; un formato di archivio non supportato';
$lang['uploadmethod'] = 'Metodo di caricamento';
$lang['uploaderstandard'] = 'Metodo di input html standard (permette la decompressione)';
$lang['enableadvanced'] = 'Abilita modalit&agrave; avanzata?';
$lang['advancedhelp'] = 'Permette di ottenere accesso a tutto il filesystem di CMSMS, non solo della cartella /upload/ (se consentito)';
$lang['showhiddenfileshelp'] = 'Effettivo solo abilitando il modo avanzato';
$lang['showhiddenfiles'] = 'Mostra file nascosti';
$lang['settingsconfirmsingledelete'] = 'Conferma l&#039;eliminazione di un file singolo?';
$lang['settingssaved'] = 'Impostazioni salvate';
$lang['help'] = '		<h3>Cosa fa?</h3>
		<p>Fornisce funzionalit&agrave; di gestione dei file</p>
		<h3>Come si usa?</h3>
		<p>Selezionalo dal menu Contenuto nella sezione di amministrazione.</p>';
?>
